@@ -78,17 +78,34 @@ dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
 
 
         this->menuBar()->addAction(tr("Options"),&opt,SLOT(show()));
-        keyopt=new keys(this);
 
-        this->menuBar()->addAction(tr("Configure keys"),keyopt,SLOT(exec()));
+
+
         this->setWindowTitle("PSX4M-Gui");
        if (!QFile("/home/opt/psx4m/keys").exists()){
            system ("mkdir -p /home/opt/psx4m");
            QMessageBox msg;
            msg.setText(tr("You should set keys to use psx4m"));
            msg.exec();
-           keyopt->exec();
+           QFile file("/opt/psx4m/keys");
+           if (!file.open(QIODevice::WriteOnly | QIODevice::Text)){
+               QMessageBox msg2;
+               msg2.setText(tr("Fatal error, check permission of file /home/opt/psx4m/keys"));
+               msg2.exec();
+               qApp->exit(1);
+               return ;
+           }else
+           {
+
+               file.close();
+               keyopt=new keys(this);
+               keyopt->exec();
+           }
+
+       }else{
+           keyopt=new keys(this);
        }
+       this->menuBar()->addAction(tr("Configure keys"),keyopt,SLOT(exec()));
 }
 void MainWindow::select_dir(){
     QString dir;
